
# Copyright 2017 Mycroft AI Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from os.path import join, exists, isfile, expanduser
from .json_helper import load_commented_json

SYSTEM_CONFIG = '/etc/mycroft/mycroft.conf'
USER_CONFIG = join(expanduser('~'), '.mycroft/mycroft.conf')

class LocalConf(dict):
    """
        Config dict from file.
    """
    def __init__(self, path):
        super(LocalConf, self).__init__()
        if path:
            self.path = path
            self.load_local(path)

    def load_local(self, path):
        """
            Load local json file into self.

            Args:
                path (str): file to load
        """
        if exists(path) and isfile(path):
            try:
                config = load_commented_json(path)
                for key in config:
                    self.__setitem__(key, config[key])

            except Exception as e:
                print("Error loading configuration '{}'".format(path))
                print(repr(e))

def get_skills_configuration_value(key):
    for config_file in (USER_CONFIG, SYSTEM_CONFIG):
        config = LocalConf(config_file)
        directory = config.get('skills').get(key)
        return directory

    return None

def get_skills_directory():
    return get_skills_configuration_value('directory') or "/opt/mycroft/skills"

def get_skills_repo_directory():
    return get_skills_configuration_value('repo_directory') or "/opt/mycroft/.skills-repo"
